==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/DataItemMigrationSummaryResultResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import kotlin.Double
import kotlin.String
import kotlin.Suppress

/**
 * Basic summary of a data item migration
 * @property endedOn Migration end time
 * @property errorPrefix Wildcard string prefix to use for querying all errors of the item
 * @property itemsCompletedCount Number of successfully completed items
 * @property itemsCount Number of items
 * @property name Name of the item
 * @property resultPrefix Wildcard string prefix to use for querying all sub-tem results of the item
 * @property startedOn Migration start time
 * @property state Current state of migration
 * @property statusMessage Status message
 */
public data class DataItemMigrationSummaryResultResponse(
    public val endedOn: String,
    public val errorPrefix: String,
    public val itemsCompletedCount: Double,
    public val itemsCount: Double,
    public val name: String,
    public val resultPrefix: String,
    public val startedOn: String,
    public val state: String,
    public val statusMessage: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.DataItemMigrationSummaryResultResponse):
            DataItemMigrationSummaryResultResponse = DataItemMigrationSummaryResultResponse(
            endedOn = javaType.endedOn(),
            errorPrefix = javaType.errorPrefix(),
            itemsCompletedCount = javaType.itemsCompletedCount(),
            itemsCount = javaType.itemsCount(),
            name = javaType.name(),
            resultPrefix = javaType.resultPrefix(),
            startedOn = javaType.startedOn(),
            state = javaType.state(),
            statusMessage = javaType.statusMessage(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/outputs/DataItemMigrationSummaryResultResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.outputs

import kotlin.Double
import kotlin.String
import kotlin.Suppress

/**
 * Basic summary of a data item migration
 * @property endedOn Migration end time
 * @property errorPrefix Wildcard string prefix to use for querying all errors of the item
 * @property itemsCompletedCount Number of successfully completed items
 * @property itemsCount Number of items
 * @property name Name of the item
 * @property resultPrefix Wildcard string prefix to use for querying all sub-tem results of the item
 * @property startedOn Migration start time
 * @property state Current state of migration
 * @property statusMessage Status message
 */
public data class DataItemMigrationSummaryResultResponse(
    public val endedOn: String,
    public val errorPrefix: String,
    public val itemsCompletedCount: Double,
    public val itemsCount: Double,
    public val name: String,
    public val resultPrefix: String,
    public val startedOn: String,
    public val state: String,
    public val statusMessage: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datamigration.outputs.DataItemMigrationSummaryResultResponse): DataItemMigrationSummaryResultResponse = DataItemMigrationSummaryResultResponse(
            endedOn = javaType.endedOn(),
            errorPrefix = javaType.errorPrefix(),
            itemsCompletedCount = javaType.itemsCompletedCount(),
            itemsCount = javaType.itemsCount(),
            name = javaType.name(),
            resultPrefix = javaType.resultPrefix(),
            startedOn = javaType.startedOn(),
            state = javaType.state(),
            statusMessage = javaType.statusMessage(),
        )
    }
}
